Package: knitr
Type: Package
Title: A General-Purpose Package for Dynamic Report Generation in R
Version: 1.49
Authors@R: c(
    person("Yihui", "Xie", role = c("aut", "cre"), email = "xie@yihui.name", comment = c(ORCID = "0000-0003-0645-5666")),
    person("Abhraneel", "Sarma", role = "ctb"),
    person("Adam", "Vogt", role = "ctb"),
    person("Alastair", "Andrew", role = "ctb"),
    person("Alex", "Zvoleff", role = "ctb"),
    person("Amar", "Al-Zubaidi", role = "ctb"),
    person("Andre", "Simon", role = "ctb", comment = "the CSS files under inst/themes/ were derived from the Highlight package http://www.andre-simon.de"),
    person("Aron", "Atkins", role = "ctb"),
    person("Aaron", "Wolen", role = "ctb"),
    person("Ashley", "Manton", role = "ctb"),
    person("Atsushi", "Yasumoto", role = "ctb", comment = c(ORCID = "0000-0002-8335-495X")),
    person("Ben", "Baumer", role = "ctb"),
    person("Brian", "Diggs", role = "ctb"),
    person("Brian", "Zhang", role = "ctb"),
    person("Bulat", "Yapparov", role = "ctb"),
    person("Cassio", "Pereira", role = "ctb"),
    person("Christophe", "Dervieux", role = "ctb"),
    person("David", "Hall", role = "ctb"),
    person("David", "Hugh-Jones", role = "ctb"),
    person("David", "Robinson", role = "ctb"),
    person("Doug", "Hemken", role = "ctb"),
    person("Duncan", "Murdoch", role = "ctb"),
    person("Elio", "Campitelli", role = "ctb"),
    person("Ellis", "Hughes", role = "ctb"),
    person("Emily", "Riederer", role = "ctb"),
    person("Fabian", "Hirschmann", role = "ctb"),
    person("Fitch", "Simeon", role = "ctb"),
    person("Forest", "Fang", role = "ctb"),
    person(c("Frank", "E", "Harrell", "Jr"), role = "ctb", comment = "the Sweavel package at inst/misc/Sweavel.sty"),
    person("Garrick", "Aden-Buie", role = "ctb"),
    person("Gregoire", "Detrez", role = "ctb"),
    person("Hadley", "Wickham", role = "ctb"),
    person("Hao", "Zhu", role = "ctb"),
    person("Heewon", "Jeon", role = "ctb"),
    person("Henrik", "Bengtsson", role = "ctb"),
    person("Hiroaki", "Yutani", role = "ctb"),
    person("Ian", "Lyttle", role = "ctb"),
    person("Hodges", "Daniel", role = "ctb"),
    person("Jacob", "Bien", role = "ctb"),
    person("Jake", "Burkhead", role = "ctb"),
    person("James", "Manton", role = "ctb"),
    person("Jared", "Lander", role = "ctb"),
    person("Jason", "Punyon", role = "ctb"),
    person("Javier", "Luraschi", role = "ctb"),
    person("Jeff", "Arnold", role = "ctb"),
    person("Jenny", "Bryan", role = "ctb"),
    person("Jeremy", "Ashkenas", role = c("ctb", "cph"), comment = "the CSS file at inst/misc/docco-classic.css"),
    person("Jeremy", "Stephens", role = "ctb"),
    person("Jim", "Hester", role = "ctb"),
    person("Joe", "Cheng", role = "ctb"),
    person("Johannes", "Ranke", role = "ctb"),
    person("John", "Honaker", role = "ctb"),
    person("John", "Muschelli", role = "ctb"),
    person("Jonathan", "Keane", role = "ctb"),
    person("JJ", "Allaire", role = "ctb"),
    person("Johan", "Toloe", role = "ctb"),
    person("Jonathan", "Sidi", role = "ctb"),
    person("Joseph", "Larmarange", role = "ctb"),
    person("Julien", "Barnier", role = "ctb"),
    person("Kaiyin", "Zhong", role = "ctb"),
    person("Kamil", "Slowikowski", role = "ctb"),
    person("Karl", "Forner", role = "ctb"),
    person(c("Kevin", "K."), "Smith", role = "ctb"),
    person("Kirill", "Mueller", role = "ctb"),
    person("Kohske", "Takahashi", role = "ctb"),
    person("Lorenz", "Walthert", role = "ctb"),
    person("Lucas", "Gallindo", role = "ctb"),
    person("Marius", "Hofert", role = "ctb"),
    person("Martin", "Modrák", role = "ctb"),
    person("Michael", "Chirico", role = "ctb"),
    person("Michael", "Friendly", role = "ctb"),
    person("Michal", "Bojanowski", role = "ctb"),
    person("Michel", "Kuhlmann", role = "ctb"),
    person("Miller", "Patrick", role = "ctb"),
    person("Nacho", "Caballero", role = "ctb"),
    person("Nick", "Salkowski", role = "ctb"),
    person("Niels Richard", "Hansen", role = "ctb"),
    person("Noam", "Ross", role = "ctb"),
    person("Obada", "Mahdi", role = "ctb"),
    person("Pavel N.", "Krivitsky", role = "ctb", comment=c(ORCID = "0000-0002-9101-3362")),
    person("Pedro", "Faria", role = "ctb"),
    person("Qiang", "Li", role = "ctb"),
    person("Ramnath", "Vaidyanathan", role = "ctb"),
    person("Richard", "Cotton", role = "ctb"),
    person("Robert", "Krzyzanowski", role = "ctb"),
    person("Rodrigo", "Copetti", role = "ctb"),
    person("Romain", "Francois", role = "ctb"),
    person("Ruaridh", "Williamson", role = "ctb"),
    person("Sagiru", "Mati", role = "ctb", comment = c(ORCID = "0000-0003-1413-3974")),
    person("Scott", "Kostyshak", role = "ctb"),
    person("Sebastian", "Meyer", role = "ctb"),
    person("Sietse", "Brouwer", role = "ctb"),
    person(c("Simon", "de"), "Bernard", role = "ctb"),
    person("Sylvain", "Rousseau", role = "ctb"),
    person("Taiyun", "Wei", role = "ctb"),
    person("Thibaut", "Assus", role = "ctb"),
    person("Thibaut", "Lamadon", role = "ctb"),
    person("Thomas", "Leeper", role = "ctb"),
    person("Tim", "Mastny", role = "ctb"),
    person("Tom", "Torsney-Weir", role = "ctb"),
    person("Trevor", "Davis", role = "ctb"),
    person("Viktoras", "Veitas", role = "ctb"),
    person("Weicheng", "Zhu", role = "ctb"),
    person("Wush", "Wu", role = "ctb"),
    person("Zachary", "Foster", role = "ctb"),
    person("Zhian N.", "Kamvar", role = "ctb", comment = c(ORCID = "0000-0003-1458-7108")),
    person(given = "Posit Software, PBC", role = c("cph", "fnd"))
    )
Description: Provides a general-purpose tool for dynamic report generation in R
    using Literate Programming techniques.
Depends: R (>= 3.6.0)
Imports: evaluate (>= 0.15), highr (>= 0.11), methods, tools, xfun (>=
        0.48), yaml (>= 2.1.19)
Suggests: bslib, codetools, DBI (>= 0.4-1), digest, formatR, gifski,
        gridSVG, htmlwidgets (>= 0.7), jpeg, JuliaCall (>= 0.11.1),
        magick, litedown, markdown (>= 1.3), png, ragg, reticulate (>=
        1.4), rgl (>= 0.95.1201), rlang, rmarkdown, sass, showtext,
        styler (>= 1.2.0), targets (>= 0.6.0), testit, tibble,
        tikzDevice (>= 0.10), tinytex (>= 0.46), webshot, rstudioapi,
        svglite
License: GPL
URL: https://yihui.org/knitr/
BugReports: https://github.com/yihui/knitr/issues
Encoding: UTF-8
VignetteBuilder: litedown, knitr
SystemRequirements: Package vignettes based on R Markdown v2 or
        reStructuredText require Pandoc (http://pandoc.org). The
        function rst2pdf() requires rst2pdf
        (https://github.com/rst2pdf/rst2pdf).
Collate: 'block.R' 'cache.R' 'utils.R' 'citation.R' 'hooks-html.R'
        'plot.R' 'defaults.R' 'concordance.R' 'engine.R' 'highlight.R'
        'themes.R' 'header.R' 'hooks-asciidoc.R' 'hooks-chunk.R'
        'hooks-extra.R' 'hooks-latex.R' 'hooks-md.R' 'hooks-rst.R'
        'hooks-textile.R' 'hooks.R' 'output.R' 'package.R' 'pandoc.R'
        'params.R' 'parser.R' 'pattern.R' 'rocco.R' 'spin.R' 'table.R'
        'template.R' 'utils-conversion.R' 'utils-rd2html.R'
        'utils-string.R' 'utils-sweave.R' 'utils-upload.R'
        'utils-vignettes.R' 'zzz.R'
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2024-11-06 23:10:53 UTC; runner
Author: Yihui Xie [aut, cre] (<https://orcid.org/0000-0003-0645-5666>),
  Abhraneel Sarma [ctb],
  Adam Vogt [ctb],
  Alastair Andrew [ctb],
  Alex Zvoleff [ctb],
  Amar Al-Zubaidi [ctb],
  Andre Simon [ctb] (the CSS files under inst/themes/ were derived from
    the Highlight package http://www.andre-simon.de),
  Aron Atkins [ctb],
  Aaron Wolen [ctb],
  Ashley Manton [ctb],
  Atsushi Yasumoto [ctb] (<https://orcid.org/0000-0002-8335-495X>),
  Ben Baumer [ctb],
  Brian Diggs [ctb],
  Brian Zhang [ctb],
  Bulat Yapparov [ctb],
  Cassio Pereira [ctb],
  Christophe Dervieux [ctb],
  David Hall [ctb],
  David Hugh-Jones [ctb],
  David Robinson [ctb],
  Doug Hemken [ctb],
  Duncan Murdoch [ctb],
  Elio Campitelli [ctb],
  Ellis Hughes [ctb],
  Emily Riederer [ctb],
  Fabian Hirschmann [ctb],
  Fitch Simeon [ctb],
  Forest Fang [ctb],
  Frank E Harrell Jr [ctb] (the Sweavel package at inst/misc/Sweavel.sty),
  Garrick Aden-Buie [ctb],
  Gregoire Detrez [ctb],
  Hadley Wickham [ctb],
  Hao Zhu [ctb],
  Heewon Jeon [ctb],
  Henrik Bengtsson [ctb],
  Hiroaki Yutani [ctb],
  Ian Lyttle [ctb],
  Hodges Daniel [ctb],
  Jacob Bien [ctb],
  Jake Burkhead [ctb],
  James Manton [ctb],
  Jared Lander [ctb],
  Jason Punyon [ctb],
  Javier Luraschi [ctb],
  Jeff Arnold [ctb],
  Jenny Bryan [ctb],
  Jeremy Ashkenas [ctb, cph] (the CSS file at
    inst/misc/docco-classic.css),
  Jeremy Stephens [ctb],
  Jim Hester [ctb],
  Joe Cheng [ctb],
  Johannes Ranke [ctb],
  John Honaker [ctb],
  John Muschelli [ctb],
  Jonathan Keane [ctb],
  JJ Allaire [ctb],
  Johan Toloe [ctb],
  Jonathan Sidi [ctb],
  Joseph Larmarange [ctb],
  Julien Barnier [ctb],
  Kaiyin Zhong [ctb],
  Kamil Slowikowski [ctb],
  Karl Forner [ctb],
  Kevin K. Smith [ctb],
  Kirill Mueller [ctb],
  Kohske Takahashi [ctb],
  Lorenz Walthert [ctb],
  Lucas Gallindo [ctb],
  Marius Hofert [ctb],
  Martin Modrák [ctb],
  Michael Chirico [ctb],
  Michael Friendly [ctb],
  Michal Bojanowski [ctb],
  Michel Kuhlmann [ctb],
  Miller Patrick [ctb],
  Nacho Caballero [ctb],
  Nick Salkowski [ctb],
  Niels Richard Hansen [ctb],
  Noam Ross [ctb],
  Obada Mahdi [ctb],
  Pavel N. Krivitsky [ctb] (<https://orcid.org/0000-0002-9101-3362>),
  Pedro Faria [ctb],
  Qiang Li [ctb],
  Ramnath Vaidyanathan [ctb],
  Richard Cotton [ctb],
  Robert Krzyzanowski [ctb],
  Rodrigo Copetti [ctb],
  Romain Francois [ctb],
  Ruaridh Williamson [ctb],
  Sagiru Mati [ctb] (<https://orcid.org/0000-0003-1413-3974>),
  Scott Kostyshak [ctb],
  Sebastian Meyer [ctb],
  Sietse Brouwer [ctb],
  Simon de Bernard [ctb],
  Sylvain Rousseau [ctb],
  Taiyun Wei [ctb],
  Thibaut Assus [ctb],
  Thibaut Lamadon [ctb],
  Thomas Leeper [ctb],
  Tim Mastny [ctb],
  Tom Torsney-Weir [ctb],
  Trevor Davis [ctb],
  Viktoras Veitas [ctb],
  Weicheng Zhu [ctb],
  Wush Wu [ctb],
  Zachary Foster [ctb],
  Zhian N. Kamvar [ctb] (<https://orcid.org/0000-0003-1458-7108>),
  Posit Software, PBC [cph, fnd]
Maintainer: Yihui Xie <xie@yihui.name>
Repository: CRAN
Date/Publication: 2024-11-08 09:30:02 UTC
Built: R 4.4.2; ; 2025-10-12 17:41:10 UTC; unix
