# Generated by roxygen2: do not edit by hand

S3method("$",knitr_strict_list)
S3method(is_low_change,default)
S3method(knit_print,default)
S3method(knit_print,knit_asis)
S3method(knit_print,knit_asis_url)
S3method(knit_print,knitr_kable)
S3method(print,knitr_kable)
S3method(sew,character)
S3method(sew,default)
S3method(sew,error)
S3method(sew,html_screenshot)
S3method(sew,knit_asis)
S3method(sew,knit_embed_url)
S3method(sew,knit_image_paths)
S3method(sew,list)
S3method(sew,message)
S3method(sew,recordedplot)
S3method(sew,source)
S3method(sew,warning)
export(Sweave2knitr)
export(all_labels)
export(all_patterns)
export(all_rcpp_labels)
export(asis_output)
export(cache_engines)
export(clean_cache)
export(combine_words)
export(convert_chunk_header)
export(current_input)
export(dep_auto)
export(dep_prev)
export(download_image)
export(engine_output)
export(extract_raw_output)
export(fig_chunk)
export(fig_path)
export(hook_ffmpeg_html)
export(hook_gifski)
export(hook_mogrify)
export(hook_movecode)
export(hook_optipng)
export(hook_pdfcrop)
export(hook_plot_asciidoc)
export(hook_plot_custom)
export(hook_plot_html)
export(hook_plot_md)
export(hook_plot_rst)
export(hook_plot_tex)
export(hook_plot_textile)
export(hook_pngquant)
export(hook_purl)
export(hook_r2swf)
export(hook_scianimator)
export(hooks_asciidoc)
export(hooks_html)
export(hooks_jekyll)
export(hooks_latex)
export(hooks_listings)
export(hooks_markdown)
export(hooks_rst)
export(hooks_sweave)
export(hooks_textile)
export(image_uri)
export(imgur_upload)
export(include_app)
export(include_graphics)
export(include_url)
export(inline_expr)
export(is_html_output)
export(is_latex_output)
export(is_low_change)
export(kable)
export(kables)
export(knit)
export(knit2html)
export(knit2pandoc)
export(knit2pdf)
export(knit2wp)
export(knit_child)
export(knit_code)
export(knit_engines)
export(knit_exit)
export(knit_expand)
export(knit_filter)
export(knit_global)
export(knit_hooks)
export(knit_meta)
export(knit_meta_add)
export(knit_params)
export(knit_params_yaml)
export(knit_patterns)
export(knit_print)
export(knit_rd)
export(knit_rd_all)
export(knit_theme)
export(knit_watch)
export(load_cache)
export(normal_print)
export(opts_chunk)
export(opts_current)
export(opts_hooks)
export(opts_knit)
export(opts_template)
export(pandoc)
export(pandoc_from)
export(pandoc_to)
export(partition_chunk)
export(pat_asciidoc)
export(pat_brew)
export(pat_html)
export(pat_md)
export(pat_rnw)
export(pat_rst)
export(pat_tex)
export(pat_textile)
export(plot_crop)
export(purl)
export(rand_seed)
export(raw_block)
export(raw_html)
export(raw_latex)
export(raw_output)
export(read_chunk)
export(read_demo)
export(read_rforge)
export(render_asciidoc)
export(render_html)
export(render_jekyll)
export(render_latex)
export(render_listings)
export(render_markdown)
export(render_rst)
export(render_sweave)
export(render_textile)
export(restore_raw_output)
export(rnw2pdf)
export(rocco)
export(rst2pdf)
export(set_alias)
export(set_header)
export(set_parent)
export(sew)
export(spin)
export(spin_child)
export(stitch)
export(stitch_rhtml)
export(stitch_rmd)
export(wrap_rmd)
export(write_bib)
import(grDevices)
import(graphics)
import(stats)
import(utils)
importFrom(xfun,attr)
importFrom(xfun,file_ext)
importFrom(xfun,file_string)
importFrom(xfun,html_escape)
importFrom(xfun,is_R_CMD_check)
importFrom(xfun,is_abs_path)
importFrom(xfun,is_windows)
importFrom(xfun,loadable)
importFrom(xfun,parse_only)
importFrom(xfun,read_utf8)
importFrom(xfun,sans_ext)
importFrom(xfun,try_silent)
importFrom(xfun,with_ext)
importFrom(xfun,write_utf8)
